@@ -1,10 +1,10 @@
+from datetime import datetime, timedelta
 from pyot.utils import loop_run
 from pyot.models import lol
-from datetime import datetime, timedelta
 
 
 def assert_team(team):
-    assert isinstance(team.team_id, int)
+    assert isinstance(team.id, int)
     assert isinstance(team.win, bool)
     assert isinstance(team.first_blood, bool)
     assert isinstance(team.first_tower, bool)
@@ -49,7 +49,7 @@ def assert_team(team):
             assert isinstance(it, lol.Rune)
         for num in stats.rune_vars:
             assert len(num) == 3
-        assert isinstance(stats.rune_style, int)
+        assert isinstance(stats.rune_main_style, int)
         assert isinstance(stats.rune_sub_style, int)
         assert isinstance(stats.kills, int)
         assert isinstance(stats.deaths, int)
@@ -109,13 +109,13 @@ def assert_team(team):
         assert isinstance(stats.total_score_rank, int)
         timeline = p.timeline
         assert isinstance(timeline.participant_id, int)
-        assert isinstance(timeline.creeps_per_min_deltas, list)
-        assert isinstance(timeline.xp_per_min_deltas, list)
-        assert isinstance(timeline.gold_per_min_deltas, list)
-        assert isinstance(timeline.cs_diff_per_min_deltas, list)
-        assert isinstance(timeline.xp_diff_per_min_deltas, list)
-        assert isinstance(timeline.damage_taken_per_min_deltas, list)
-        assert isinstance(timeline.damage_taken_diff_per_min_deltas, list)
+        assert isinstance(timeline.creeps_per_min_deltas, dict)
+        assert isinstance(timeline.xp_per_min_deltas, dict)
+        assert isinstance(timeline.gold_per_min_deltas, dict)
+        assert isinstance(timeline.cs_diff_per_min_deltas, dict)
+        assert isinstance(timeline.xp_diff_per_min_deltas, dict)
+        assert isinstance(timeline.damage_taken_per_min_deltas, dict)
+        assert isinstance(timeline.damage_taken_diff_per_min_deltas, dict)
         assert isinstance(timeline.role, str)
         assert isinstance(timeline.lane, str)
 
@@ -134,12 +134,10 @@ async def async_match():
     assert isinstance(match.platform, str)
     for team in match.teams:
         assert_team(team)
-    assert_team(match.blue_team)
-    assert_team(match.red_team)
 
 
 async def async_match_timeline():
-    match = await lol.MatchTimeline(id=3517707030, platform="NA1").get()
+    match = await lol.Match(id=3517707030, include_timeline=True, platform="NA1").get()
     assert isinstance(match.id, int)
     assert isinstance(match.type, str)
     assert isinstance(match.mode, str)
@@ -152,46 +150,32 @@ async def async_match_timeline():
     assert isinstance(match.platform, str)
     for team in match.teams:
         assert_team(team)
-    assert_team(match.blue_team)
-    assert_team(match.red_team)
     for team in match.teams:
         for p in team.participants:
             for event in p.timeline.events:
                 assert isinstance(event, lol.match.MatchEventData)
             for frame in p.timeline.frames:
                 assert isinstance(frame, lol.match.MatchFrameData)
-    blue_team = match.blue_team
-    red_team = match.red_team
-    blue_team2 = match.teams[0] if match.teams[0].team_id == 100 else match.teams[1]
-    red_team2 = match.teams[1] if match.teams[1].team_id == 200 else match.teams[0]
+    blue_team2 = match.teams[0] if match.teams[0].id == 100 else match.teams[1]
+    red_team2 = match.teams[1] if match.teams[1].id == 200 else match.teams[0]
     for i in range(5):
-        frame_len = len(blue_team2.participants[i].timeline.frames)
-        event_len = len(blue_team2.participants[i].timeline.events)
-        for j in range(frame_len):
-            assert blue_team2.participants[i].timeline.frames[j].minions_killed == blue_team.participants[i].timeline.frames[j].minions_killed
-        for j in range(event_len):
-            assert blue_team2.participants[i].timeline.events[j].type == blue_team.participants[i].timeline.events[j].type
+        assert len(blue_team2.participants[i].timeline.frames) > 30
+        assert len(blue_team2.participants[i].timeline.events) > 50
     for i in range(5):
-        frame_len = len(red_team2.participants[i].timeline.frames)
-        event_len = len(red_team2.participants[i].timeline.events)
-        for j in range(frame_len):
-            assert red_team2.participants[i].timeline.frames[j].minions_killed == red_team.participants[i].timeline.frames[j].minions_killed
-        for j in range(event_len):
-            assert red_team2.participants[i].timeline.events[j].type == red_team.participants[i].timeline.events[j].type
+        assert len(red_team2.participants[i].timeline.frames) > 30
+        assert len(red_team2.participants[i].timeline.events) > 50
 
 
 async def async_timeline():
     timeline = await lol.Timeline(id=3517707030, platform="NA1").get()
     assert isinstance(timeline.interval, timedelta)
     assert timeline.interval == timedelta(seconds=60)
-    for event in timeline.events:
-        assert isinstance(event, lol.match.MatchEventMinuteData)
-        for e in event:
-            assert isinstance(e, lol.match.MatchEventData)
     for frame in timeline.frames:
         assert isinstance(frame, lol.match.MatchFrameMinuteData)
-        for f in frame:
+        for f in frame.participant_frames:
             assert isinstance(f, lol.match.MatchFrameData)
+        for e in frame.events:
+            assert isinstance(e, lol.match.MatchEventData)
 
 
 async def async_match_history():
@@ -212,7 +196,6 @@ async def async_match_history():
         assert isinstance(match.role, str)
         assert isinstance(match.lane, str)
         assert isinstance(match.match, lol.Match)
-        assert isinstance(match.match_timeline, lol.MatchTimeline)
         assert isinstance(match.champion, lol.Champion)
 
 
