@@ -4,4 +4,4 @@ from pyot.models import lol
 
 def test_status():
     status = loop_run(lol.Status(platform="na1").get())
-    status.dict(pyotify=True)
\ No newline at end of file
+    status.dict(recursive=True)
\ No newline at end of file
